library(ggplot2)
library(gridExtra)
############################## Read Data from a .txt File ##################################################

### ############# 1.Load the data file in RStudio ############## ###

Tabbats <- read.table("Tabbats.txt", header = TRUE,      #header = TRUE, means that we use 
                      stringsAsFactors = FALSE)          #the first row as the column names.
###Print table###       
Tabbats ## This command will print the whole table.

###View the 5 first row of your table###
head(Tabbats, 5) ## you can pass in argument the number of row you want to show in your head(Table, nrow) command.

###str() Command###
str(Tabbats) ## str() will give you useful information as the number of observations your doing and how many variables are you using
              # as well as the type of each of your variables.

###summary() Command###
summary(Tabbats) ## summary() will give you the minimum, maximum and mean of each column dataset as well as the
                  #first and third quartile and the median. You can directly now the repartition of your data using this command.

## Try to summarize the BOW variable only
summary(Tabbats$BOW)

###subset() Command###
subset(Tabbats, Tabbats$BOW > 200) ## Here we subset our table by keeping all the rows where the condition BOW>200 is met.

Tabbats[Tabbats$BOW>200,] ## Another way of subsetting your table

##Try to get the species name only where the condition BRW > 3000 is met

##All the species with a BRW superior to 3000
Tabbats$Species[Tabbats$BRW>3000]
subset(Tabbats$Species, Tabbats$BRW>200)

###sum() Command###
##How many bats have a BOW less than 200
xc <- sum(Tabbats$BOW<200)
xc

### ############# 2.Visualize your data ############## ###
##We will run multiple plot option on the BOW variable of our table

###Simple plot using qplot()###
g1 <- qplot(data = Tabbats, x=BOW) ## very simple hstogram plot with not many details
g1

###Plot using ggplot()###
g2 <- ggplot(data=Tabbats, aes(x=BOW))+ ##More detailed plot that use the ggplot fct
  geom_histogram(binwidth = 20)+         #This representation is closer to the actual data we have
  coord_cartesian(xlim = c(0,1015))+     #Our data is represented in a histogram
  scale_x_continuous(breaks = seq(0,1015,50))+
  scale_y_continuous(breaks = seq(0,15,1.5))
g2

###Another representation using points###
g3 <- ggplot(data=Tabbats, aes(x=BOW, y=1:29))+ 
  geom_point()+
  coord_cartesian(xlim = c(0,1015))+
  scale_x_continuous(breaks = seq(0,1015,50))
g3

###Compare the 3 plots###
grid.arrange(g1, g2, g3, ncol=1)

###################################################################################################################

############################## Read Data from a .csv File ##################################################

### ############# 1.Load the data file in RStudio ############## ###
StateInfo <- read.csv('StateData_UDACITY.csv', stringsAsFactors = FALSE)

###Exercise 1###

##1.1.1 How many variables are in the dataset?##
str(StateInfo) ## 12 Variables

##1.1.2 How many observations are in the dataset?##
str(StateInfo) ## 50 Observations

##1.2 Find the state which have the highest murder rate using the subset() command##
##Option 1##
xc = 0                            ##In this example we use a for loop with an if statement
for (i in 1:nrow(StateInfo)){     ##This option takes more time and ressources than the following
  if(StateInfo$murder[i]>xc){     #easier option.
    xc = StateInfo$murder[i]
  }
}
xc
Crime<-StateInfo[StateInfo$murder ==xc,]
Crime

##Option 2##
summary(StateInfo$murder) ## max = 15.1
subset(StateInfo, StateInfo$murder==15.1)

##Option 3##
subset(StateInfo, StateInfo$murder==max(StateInfo$murder)) ##we get the max of murder using the max() command

##How many states have a life expectancy superior to 73?##
sum(StateInfo$life.exp>73) ## Only 1 state have life expectancy superior to 73 years


###Exercise 2###
str(StateInfo)

StateInfo$security <- NA
StateInfo$security[StateInfo$murder<7] <- "secure"
StateInfo$security[StateInfo$murder>7] <- "dangerous"

str(StateInfo)
head(StateInfo)

###Illiteracy rate vs security###
summary(StateInfo$illiteracy) ##Pay attention to the minimum and maximum

##Illiteracy Histogram / Security
h1 <- ggplot(data = StateInfo, aes(x = illiteracy))+ ##You can change the value of X to analyze different variables
  geom_histogram(binwidth = 0.1)+ ##Try to use different values and see how it affect your plot
  scale_x_continuous(breaks = seq(0.5, 2.8, 0.2))+##those values were taken from running the summary() command
  facet_wrap(~security, scales = 'free')
h1

##Illiteracy Boxplot / Security
h2 <- ggplot(data = StateInfo, aes(y = illiteracy))+
  geom_boxplot()+
  scale_y_continuous(breaks = seq(0.5, 2.8, 0.2))+
  facet_wrap(~security, scales = 'free')
h2


###HighSchool Graduation rate vs security###
summary(StateInfo$highSchoolGrad)

h1 <- ggplot(data = StateInfo, aes(x = highSchoolGrad))+
  geom_histogram()+
  scale_x_continuous(breaks = seq(35, 70, 2))+
  facet_wrap(~security, scales = 'free')
h1

h2 <- ggplot(data = StateInfo, aes(y = highSchoolGrad))+
  geom_boxplot()+
  scale_y_continuous(breaks = seq(35, 70, 2))+
  facet_wrap(~security, scales = 'free')
h2

